################################################################################################################################################################################
# wxPyMail_gui.py
#
# Created: June 6, 2008
# Author:  Mike Driscoll
# email:   mike@pythonlibrary.org
#
# Feel free to email with questions, comments, or suggestions
#################################################################################################################################################################################

import os
import sys
import urllib
import wx

import mail_ico

class SendMailWx(wx.Frame):
    def __init__(self):
        wx.Frame.__init__(self, None, -1, 'New Email Message (Plain Text)',
                          size=(600,400))
        self.panel = wx.Panel(self, wx.ID_ANY)

        # set your email address here
        self.email = 'myEmail@email.com'

        self.filepaths = []        
        self.currentDir = os.path.abspath(os.path.dirname(sys.argv[0])) 
        
        self.createMenu()
        self.createToolbar()
        self.createWidgets()
        try:
            print sys.argv
            self.parseURL(sys.argv[1])
        except Exception, e:
            print 'Unable to execute parseURL...'
            print e
        
        self.layoutWidgets()
        
        self.attachTxt.Hide()
        self.editAttachBtn.Hide()

    def createMenu(self):
        menubar = wx.MenuBar()
        
        fileMenu = wx.Menu()
        send_menu_item = fileMenu.Append(wx.NewId(), '&Send', 'Sends the email')
        close_menu_item = fileMenu.Append(wx.NewId(), '&Close', 'Closes the window')
        menubar.Append(fileMenu, '&File')
        self.SetMenuBar(menubar)

        # bind events to the menu items
        self.Bind(wx.EVT_MENU, self.onSend, send_menu_item)
        self.Bind(wx.EVT_MENU, self.onClose, close_menu_item)

    def createToolbar(self):
        toolbar = self.CreateToolBar(wx.TB_3DBUTTONS|wx.TB_TEXT)
        toolbar.SetToolBitmapSize((31,31))
        bmp = mail_ico.getBitmap()
        sendTool = toolbar.AddSimpleTool(-1, bmp, 'Send', 'Sends Email')
        self.Bind(wx.EVT_MENU, self.onSend, sendTool)        
        toolbar.Realize()

    def createWidgets(self):
        p = self.panel
        
        font = wx.Font(10, wx.SWISS, wx.NORMAL, wx.BOLD)
        self.fromLbl    = wx.StaticText(p, wx.ID_ANY, 'From', size=(60,-1))
        self.fromTxt    = wx.TextCtrl(p, wx.ID_ANY, self.email)
        self.toLbl      = wx.StaticText(p, wx.ID_ANY, 'To:', size=(60,-1))
        self.toTxt      = wx.TextCtrl(p, wx.ID_ANY, '')
        self.subjectLbl = wx.StaticText(p, wx.ID_ANY, ' Subject:', size=(60,-1))
        self.subjectTxt = wx.TextCtrl(p, wx.ID_ANY, '')
        self.attachBtn  = wx.Button(p, wx.ID_ANY, 'Attachments')        
        self.attachTxt  = wx.TextCtrl(p, wx.ID_ANY, '', style=wx.TE_MULTILINE)
        self.attachTxt.Disable()
        self.editAttachBtn = wx.Button(p, wx.ID_ANY, 'Edit Attachments')
        
        self.messageTxt = wx.TextCtrl(p, wx.ID_ANY, '', style=wx.TE_MULTILINE)

        self.Bind(wx.EVT_BUTTON, self.onAttach, self.attachBtn)
        self.Bind(wx.EVT_BUTTON, self.onAttachEdit, self.editAttachBtn)

        self.fromLbl.SetFont(font)
        self.toLbl.SetFont(font)
        self.subjectLbl.SetFont(font)

    def layoutWidgets(self):
        mainSizer = wx.BoxSizer(wx.VERTICAL)
        fromSizer = wx.BoxSizer(wx.HORIZONTAL)
        toSizer   = wx.BoxSizer(wx.HORIZONTAL)
        subjSizer = wx.BoxSizer(wx.HORIZONTAL)
        attachSizer = wx.BoxSizer(wx.HORIZONTAL)

        fromSizer.Add(self.fromLbl, 0)
        fromSizer.Add(self.fromTxt, 1, wx.EXPAND)
        toSizer.Add(self.toLbl, 0)
        toSizer.Add(self.toTxt, 1, wx.EXPAND)
        subjSizer.Add(self.subjectLbl, 0)
        subjSizer.Add(self.subjectTxt, 1, wx.EXPAND)
        attachSizer.Add(self.attachBtn, 0, wx.ALL, 5)
        attachSizer.Add(self.attachTxt, 1, wx.ALL|wx.EXPAND, 5)
        attachSizer.Add(self.editAttachBtn, 0, wx.ALL, 5)

        mainSizer.Add(fromSizer, 0, wx.ALL|wx.EXPAND, 5)
        mainSizer.Add(toSizer, 0, wx.ALL|wx.EXPAND, 5)
        mainSizer.Add(subjSizer, 0, wx.ALL|wx.EXPAND, 5)
        mainSizer.Add(attachSizer, 0, wx.ALL|wx.EXPAND, 5)
        mainSizer.Add(self.messageTxt, 1, wx.ALL|wx.EXPAND, 5)        
        self.panel.SetSizer(mainSizer)
        self.panel.Layout()

    def parseURL(self, url):
        ''' Parse the URL passed from the mailto link '''
        sections = 1
        mailto_string = url.split(':')[1]               
        
        if '?' in mailto_string:
            sections = mailto_string.split('?')
        else:
            address = mailto_string
            
        if sections > 1:
            address = sections[0]
            new_sections = urllib.unquote(sections[1]).split('&')
            for item in new_sections:
                if 'subject' in item.lower():
                    Subject = item.split('=')[1]
                    self.subjectTxt.SetValue(Subject)
                if 'body' in item.lower():
                    Body = item.split('=')[1]
                    self.messageTxt.SetValue(Body)
                    
        self.toTxt.SetValue(address)

    def onAttach(self, event):
        print "in onAttach method..."

    def onAttachEdit(self, event):
        print "in onAttachEdit method..."

    def onSend(self, event):
        print "in onSend event handler..."

    def onClose(self, event):
        self.Close()
                    
#######################
# Start program
if __name__ == '__main__':
    app = wx.PySimpleApp()
    frame = SendMailWx()
    frame.Show()
    app.MainLoop() 
